Decrypt

Trait Decrypt 

pub trait Decrypt {
    type Media;
    type Keys;
    type Error;

    // Required method
    fn decrypt(
        &self,
        media: &mut Self::Media,
        keys: &Self::Keys,
    ) -> Result<(), Self::Error>;
}
Remove sample protection from a media representation, in place.

The inverse of Encrypt. Self::Keys is the key material required to unprotect the samples (e.g. per-key-ID content keys).

Required Associated Types

type Media

The in-memory media representation operated on in place.

type Keys

The key material required to unprotect samples.

type Error

The error type this implementer returns.

Required Methods

fn decrypt( &self, media: &mut Self::Media, keys: &Self::Keys, ) -> Result<(), Self::Error>

Decrypt the protected samples in media in place using keys.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors